summaryrefslogtreecommitdiff
path: root/src/chmod.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-11-27 05:34:31 +0000
committerJim Meyering <jim@meyering.net>1995-11-27 05:34:31 +0000
commit57ec0f45c90bde207866d65aa7752d56cd55ac04 (patch)
tree5e7ed870725ad3f21baf9fc96bac635fe8b10d85 /src/chmod.c
parenta7830ac93b955ac0be4a15d65a3e5a67f1635b8b (diff)
downloadcoreutils-57ec0f45c90bde207866d65aa7752d56cd55ac04.tar.xz
s/non-zero/nonzero/g
Diffstat (limited to 'src/chmod.c')
-rw-r--r--src/chmod.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/chmod.c b/src/chmod.c
index eb7116b0d..cae5d7e65 100644
--- a/src/chmod.c
+++ b/src/chmod.c
@@ -57,10 +57,10 @@ static int verbose;
/* If nonzero, describe only modes that change. */
static int changes_only;
/* If non-zero, display usage information and exit. */
static int show_help;
/* If non-zero, print the version on standard output and exit. */
static int show_version;
static struct option const long_options[] =
@@ -94,7 +94,7 @@ describe_change (char *file, short unsigned int mode, int changed)
}
/* Change the mode of FILE according to the list of operations CHANGES.
- If DEREF_SYMLINK is non-zero and FILE is a symbolic link, change the
+ If DEREF_SYMLINK is nonzero and FILE is a symbolic link, change the
mode of the referenced file. If DEREF_SYMLINK is zero, ignore symbolic
links. Return 0 if successful, 1 if errors occurred. */
@@ -57,10 +57,10 @@ static int verbose;
/* If nonzero, describe only modes that change. */
static int changes_only;
-/* If non-zero, display usage information and exit. */
+/* If nonzero, display usage information and exit. */
static int show_help;
@@ -57,10 +57,10 @@ static int verbose;
static int show_help;
-/* If non-zero, print the version on standard output and exit. */
+/* If nonzero, print the version on standard output and exit. */
static int show_version;
static struct option const long_options[] =